validate_project_exists

Function validate_project_exists 

pub async fn validate_project_exists(
    pool: &SqlitePool,
    uuid: &Uuid,
) -> Result<()>
Validate that a project exists (project is a task with type = 1)

Errors

Returns an error if the project does not exist, is trashed, or if the database query fails