pub async fn validate_project_exists(
pool: &SqlitePool,
uuid: &Uuid,
) -> Result<()>Expand description
Validate that a project exists (project is a task with type = 1)
Errors
Returns an error if the project does not exist, is trashed, or if the database query fails