pub async fn validate_task_exists(
pool: &SqlitePool,
id: &ThingsId,
) -> Result<()>Expand description
Validate that a task exists and is not trashed
Errors
Returns an error if the task does not exist, is trashed, or if the database query fails